"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.decodeToken = exports.generateToken = exports.protect = void 0;
const jsonwebtoken_1 = __importDefault(require("jsonwebtoken"));
const express_async_handler_1 = __importDefault(require("express-async-handler"));
const userModel_1 = require("../models/userModel");
const errorMiddleware_1 = require("./errorMiddleware");
exports.protect = (0, express_async_handler_1.default)((req, res, next) => __awaiter(void 0, void 0, void 0, function* () {
    let token;
    if (req.headers.authorization &&
        req.headers.authorization.startsWith('Bearer')) {
        try {
            // Get token from header
            token = req.headers.authorization.split(' ')[1];
            // Verify token
            const decoded = jsonwebtoken_1.default.verify(token, process.env.JWT_SECRET);
            // Get user from the token
            req.user = yield userModel_1.User.findById(decoded.id).select('-password');
            if (req.user.token == token) {
                next();
            }
            else {
                res.status(401);
                throw new Error('Unauthorized.');
            }
        }
        catch (error) {
            console.log(error);
            res.status(401);
            throw new Error('Not authorized');
        }
    }
    if (!token) {
        res.status(401);
        throw new Error('Not authorized, no token');
    }
}));
// Generate JWT
const generateToken = (id, role, name, email) => {
    return jsonwebtoken_1.default.sign({ id, role, name, email }, process.env.JWT_SECRET, {
        expiresIn: '3d'
    });
};
exports.generateToken = generateToken;
// Decode JWT token
const decodeToken = (token) => {
    try {
        const base64Payload = token.split(".")[1];
        const payloadBuffer = Buffer.from(base64Payload, "base64");
        return JSON.parse(payloadBuffer.toString());
    }
    catch (error) {
        throw new errorMiddleware_1.ValidationError(error);
    }
};
exports.decodeToken = decodeToken;
//# sourceMappingURL=authMiddleware.js.map